@@ -21,7 +21,7 @@ impl MachineDeployment {
         self
     }
 
-    pub fn bootstrap_config_ref(mut self, template: ControlPlaneConfigTemplate) -> Self {
+    pub fn bootstrap_config_ref(mut self, template: &ControlPlaneConfigTemplate) -> Self {
         let config_ref = template.object_ref();
         let mut spec = self.spec.template.spec.take().unwrap_or_default();
         spec.bootstrap.config_ref = Some(config_ref);
